@@ -47,27 +47,6 @@ USER_ALREADY_LOGGED_ON_KEY = "pl-user.USER_ALREADY_LOGGED_ON"
 DEVICE_ALREADY_LOGGED_ON_KEY = "pl-user.DEVICE_ALREADY_LOGGED_ON_KEY"
 
 
-class _ForceLogout:
-    def __init__(self, userUuid, deviceToken):
-        self._userUuid = userUuid
-        self._deviceToken = deviceToken
-
-    def forceDbLogout(self, ormSession):
-        ormSession.query(UserLoggedIn).filter(
-            UserLoggedIn.userUuid == self._userUuid
-        ).filter(UserLoggedIn.deviceToken == self._deviceToken).delete(
-            synchronize_session=False
-        )
-
-    def notify(self, clientTupleObservable):
-        clientTupleObservable.notifyOfTupleUpdate(
-            TupleSelector(
-                UserLoggedInTuple.tupleType(),
-                selector=dict(deviceToken=self._deviceToken),
-            )
-        )
-
-
 class LoginLogoutController:
     def __init__(
         self, deviceApi: DeviceApiABC, dbSessionCreator: DbSessionCreator
@@ -241,8 +220,6 @@ class LoginLogoutController:
         isFieldService = loginTuple.isFieldService
         allowMultipleLogins = isFieldService
 
-        forceLogouter = None
-
         responseTuple = UserLoginResponseTuple(
             userName=userName,
             userToken="Not implemented",
@@ -312,10 +289,9 @@ class LoginLogoutController:
             # If the user is logged in, but not to this client device, raise exception
             if allowMultipleLogins and userLoggedIn and not sameDevice:
                 if USER_ALREADY_LOGGED_ON_KEY in acceptedWarningKeys:
-                    forceLogouter = _ForceLogout(
-                        userUuid, loggedInElsewhere.deviceToken
+                    self._forceLogout(
+                        ormSession, userUuid, loggedInElsewhere.deviceToken
                     )
-                    forceLogouter.forceDbLogout(ormSession)
                     userLoggedIn = False
 
                 else:
@@ -339,12 +315,11 @@ class LoginLogoutController:
 
                     # Else, The old device has been deleted,
                     # Just let them login to the same device.
-
-                    forceLogouter = _ForceLogout(
+                    self._forceLogout(
+                        ormSession,
                         loggedInElsewhere.userUuid,
                         loggedInElsewhere.deviceToken,
                     )
-                    forceLogouter.forceDbLogout(ormSession)
 
             # If we're logging into the same device, but already logged in
             if sameDevice:  # Logging into the same device
@@ -369,11 +344,11 @@ class LoginLogoutController:
             if anotherUserOnThatDevice:
                 anotherUserOnThatDevice = anotherUserOnThatDevice[0]
                 if DEVICE_ALREADY_LOGGED_ON_KEY in acceptedWarningKeys:
-                    forceLogouter = _ForceLogout(
+                    self._forceLogout(
+                        ormSession,
                         anotherUserOnThatDevice.userUuid,
                         anotherUserOnThatDevice.deviceToken,
                     )
-                    forceLogouter.forceDbLogout(ormSession)
 
                 else:
                     responseTuple.setFailed()
@@ -411,9 +386,6 @@ class LoginLogoutController:
         finally:
             ormSession.close()
 
-            if forceLogouter:
-                forceLogouter.notify(self._clientTupleObservable)
-
     @inlineCallbacks
     def login(self, loginTuple: UserLoginAction):
         """
@@ -463,3 +435,18 @@ class LoginLogoutController:
         )
 
         return loginResponse
+
+    def _forceLogout(self, ormSession, userUuid, deviceToken):
+
+        ormSession.query(UserLoggedIn).filter(
+            UserLoggedIn.userUuid == userUuid
+        ).filter(UserLoggedIn.deviceToken == deviceToken).delete(
+            synchronize_session=False
+        )
+
+        self._clientTupleObservable.notifyOfTupleUpdate(
+            TupleSelector(
+                UserLoggedInTuple.tupleType(),
+                selector=dict(deviceToken=deviceToken),
+            )
+        )
